Learn R Programming

diemr (version 1.5.2)

readIncludedSites: Read genomic sites from a BED-like file

Description

Imports a BED-like file and optionally subsets sites.

Usage

readIncludedSites(includedSites, ChosenSites = "all")

Value

A data frame containing the selected sites with 1-based coordinates.

Arguments

includedSites

Path to a BED-like file, ideally output from vcf2diem.

ChosenSites

Logical or numeric vector specifying sites to retain, or "all" to keep all sites.

Examples

Run this code
if (FALSE) {
# Run this example in a working directory with write permissions
myo <- system.file("extdata", "myotis.vcf", package = "diemr")
vcf2diem(myo, "myo")
readIncludedSites("myo-001.txt")
readIncludedSites("myo-001.txt", ChosenSites = 2:7)
}

Run the code above in your browser using DataLab