Learn R Programming

diemr (version 1.5.2)

resolveCompartments: Resolve compartments for diem input files

Description

Generates a list of logical vectors indicating which sites should be compartmentalized. If toBeCompartmentalized is "all", all sites are marked as TRUE. Otherwise, a logical vector must be provided with a length matching the total number of sites.

Usage

resolveCompartments(files, toBeCompartmentalized, compartmentSizes = NULL)

Value

A list of logical vectors corresponding to each file.

Arguments

files

Paths to diem input files.

toBeCompartmentalized

Either "all" or a logical vector specifying sites to compartmentalize.

compartmentSizes

Optional vector specifying the number of sites per file.