Generates a list of logical vectors indicating which sites should be compartmentalized.
If toBeCompartmentalized is "all", all sites are marked as TRUE. Otherwise, a logical vector
must be provided with a length matching the total number of sites.
resolveCompartments(files, toBeCompartmentalized, compartmentSizes = NULL)A list of logical vectors corresponding to each file.
Paths to diem input files.
Either "all" or a logical vector specifying sites to compartmentalize.
Optional vector specifying the number of sites per file.