Determines the most frequent genomic state in a given interval, weighted by Laplace-scaled probabilities.
unbiasedWeightedStateChoice(genomicStates, laplaceWeights)A character representing the most probable genomic state.
A character vector of genomic states.
A numeric vector of weights.
In case of ties, states are ranked by:
Total sum of weights (higher is preferred).
Highest single weight assigned to any occurrence of the state (higher is preferred).
Lexicographic order (earlier in the alphabet is preferred).